@@ -24,13 +24,13 @@
 #define OKTETA_ABSTRACTBYTEARRAYMODEL_H
 
 // lib
-#include "oktetacore_export.h"
-#include "addressrange.h"
-#include "size.h"
-#include "byte.h"
+#include <okteta/oktetacore_export.h>
+#include <okteta/addressrange.h>
+#include <okteta/size.h>
+#include <okteta/byte.h>
 // Qt
-#include <QtCore/QObject>
-#include <QtCore/QByteArray>
+#include <QObject>
+#include <QByteArray>
 
 
 namespace Okteta
