@@ -24,7 +24,7 @@
 #define TEXTCHARCODECTEST_H
 
 // Qt
-#include <QtCore/QObject>
+#include <QObject>
 
 namespace Okteta
 {
