@@ -31,15 +31,15 @@
 // lib
 #include <abstractcolumnstylist.h>
 // Okteta core
-#include <bookmarkable.h>
-#include <bookmarksconstiterator.h>
-#include <bookmark.h>
-#include <charcodec.h>
+#include <okteta/bookmarkable.h>
+#include <okteta/bookmarksconstiterator.h>
+#include <okteta/bookmark.h>
+#include <okteta/charcodec.h>
 // KF5
 #include <KColorScheme>
 // Qt
-#include <QtGui/QPainter>
-#include <QtGui/QFontMetrics>
+#include <QPainter>
+#include <QFontMetrics>
 
 
 namespace Okteta
