@@ -19,7 +19,7 @@
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
-#include <QtTest/QtTest>
+#include <QTest>
 #include <QScriptValue>
 #include <QScriptEngine>
 #include <limits>
