@@ -24,9 +24,9 @@
 #define CHECKSUMCALCULATEJOB_H
 
 // Okteta core
-#include <addressrange.h>
+#include <okteta/addressrange.h>
 // Qt
-#include <QtCore/QObject>
+#include <QObject>
 
 class AbstractByteArrayChecksumAlgorithm;
 
@@ -35,7 +35,7 @@ class AbstractByteArrayModel;
 }
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class ChecksumCalculateJob : public QObject // not yet: KJob
