@@ -24,12 +24,12 @@
 #define INFOTOOLFACTORY_H
 
 // lib
-#include "oktetakastencontrollers_export.h"
+#include <kasten/okteta/oktetakastencontrollers_export.h>
 // Kasten core
-#include <abstracttoolfactory.h>
+#include <kasten/abstracttoolfactory.h>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class OKTETAKASTENCONTROLLERS_EXPORT InfoToolFactory : public AbstractToolFactory
