@@ -20,40 +20,42 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "uint32codec.hpp"
+#include "uint32codec.h"
 
 // tool
-#include "../types/uint32.hpp"
-#include "../poddata.hpp"
-// KF
+#include "../types/uint32.h"
+#include "../poddata.h"
+// KF5
 #include <KLocalizedString>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 UInt32Codec::UInt32Codec()
-    : AbstractTypeCodec(i18nc("@label:textbox", "Unsigned 32-bit"))
+  : AbstractTypeCodec( i18nc("@label:textbox","Unsigned 32-bit") )
 {}
 
-UInt32Codec::~UInt32Codec() = default;
-
-QVariant UInt32Codec::value(const PODData& data, int* byteCount) const
+QVariant UInt32Codec::value( const PODData& data, int* byteCount ) const
 {
-    const quint32* pointer = (quint32*)data.pointer(4);
+    const quint32* pointer = (quint32*)data.pointer( 4 );
 
     *byteCount = pointer ? 4 : 0;
-    return pointer ? QVariant::fromValue<UInt32>(UInt32(*pointer)) : QVariant();
+    return pointer ? QVariant::fromValue<UInt32>( UInt32(*pointer) ) : QVariant();
 }
 
-QByteArray UInt32Codec::valueToBytes(const QVariant& value) const
+QByteArray UInt32Codec::valueToBytes( const QVariant& value ) const
 {
     const quint32 number = value.value<UInt32>().value;
 
-    return QByteArray((const char*)&number, sizeof(quint32));
+    return QByteArray( (const char*)&number, sizeof(quint32) );
 }
 
-bool UInt32Codec::areEqual(const QVariant& value, QVariant& otherValue) const
+bool UInt32Codec::areEqual( const QVariant& value, QVariant& otherValue ) const
 {
-    return (value.value<UInt32>().value == otherValue.value<UInt32>().value);
+    return ( value.value<UInt32>().value == otherValue.value<UInt32>().value );
 }
 
+UInt32Codec::~UInt32Codec() {}
+
 }
