@@ -23,10 +23,10 @@
 #ifndef PRINTCOLUMNSTYLIST_H
 #define PRINTCOLUMNSTYLIST_H
 
-// lib
-#include <abstractcolumnstylist.h>
+// Okteta gui
+#include <okteta/abstractcolumnstylist.h>
 // Qt
-#include <QtGui/QPalette>
+#include <QPalette>
 
 
 namespace Okteta
