@@ -24,55 +24,50 @@
 
 // controller
 #include "searchtool.h"
-// KDE
-#include <KLocale>
-// #include <kstandardguiitem.h>
+// KF5
+#include <KLocalizedString>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 KSearchDialog::KSearchDialog( SearchTool* tool, QWidget* parent )
   : KAbstractFindDialog( parent ),
     mTool( tool )
 {
-    setCaption( i18nc("@title:window","Find Bytes") );
-    setButtonGuiItem( Ok, KGuiItem( i18nc("@action:button","&Find"),
-                      QLatin1String("edit-find"),
-                      i18nc("@info:tooltip","Start searching"),
-                      i18nc("@info:whatsthis",
-                            "If you press the <interface>Find</interface> button, "
-                            "the bytes you entered above are searched for within "
-                            "the byte array.")) );
+    setWindowTitle( i18nc("@title:window","Find Bytes") );
+
+    setFindButton( i18nc("@action:button","&Find"),
+                   QStringLiteral("edit-find"),
+                   i18nc("@info:tooltip","Start searching"),
+                   xi18nc("@info:whatsthis",
+                          "If you press the <interface>Find</interface> button, "
+                          "the bytes you entered above are searched for within "
+                          "the byte array.") );
 
     setupFindBox();
     setupOperationBox();
     setupCheckBoxes();
 
-    enableButtonOk( false );
+    setFindButtonEnabled( false );
     setModal( false );
 
     setCharCodec( mTool->charCodingName() );
-    connect( mTool,  SIGNAL(charCodecChanged(QString)),
-             SLOT(setCharCodec(QString)) );
+    connect( mTool,  &SearchTool::charCodecChanged,
+             this, &KSearchDialog::setCharCodec );
 }
 
 
-void KSearchDialog::slotButtonClicked( int button )
+void KSearchDialog::onFindButtonClicked()
 {
-    if( button != KDialog::Ok )
-        KAbstractFindDialog::slotButtonClicked( button );
-    else
-    {
-        hide();
+    hide();
 
-        rememberCurrentSettings();
+    rememberCurrentSettings();
 
-        mTool->setSearchData( data() );
-        mTool->setCaseSensitivity( caseSensitivity() );
+    mTool->setSearchData( data() );
+    mTool->setCaseSensitivity( caseSensitivity() );
 
-        mTool->search( direction(), fromCursor(), inSelection() );
-    }
+    mTool->search( direction(), fromCursor(), inSelection() );
 }
 
 void KSearchDialog::showEvent( QShowEvent* showEvent )
