@@ -62,6 +62,8 @@ public:
     virtual void resetValidationState();
     virtual void calculateValidationState();
 
+    virtual bool isDataInformationWithChildren() const;
+
     /** Takes ownership! */
     void appendChild(DataInformation* child, bool emitSignal = true);
     /** Takes ownership of all elements */
@@ -84,4 +86,9 @@ inline bool DataInformationWithChildren::canHaveChildren() const
     return true;
 }
 
+inline bool DataInformationWithChildren::isDataInformationWithChildren() const
+{
+    return true;
+}
+
 #endif /* DATAINFORMATIONWITHCHILDREN_H_ */
