@@ -41,6 +41,7 @@ public:
     virtual void setWidgetData(QWidget* w) const;
     /** sign extend the value if it is negative, so it can always be treated as a plain qint64 */
     virtual void setValue(AllPrimitiveTypes newVal);
+    virtual Type bitfieldType() const;
 private:
     virtual QString valueStringImpl() const;
     virtual QString typeNameImpl() const;
@@ -52,4 +53,9 @@ inline QString SignedBitfieldDataInformation::typeNameImpl() const
             width());
 }
 
+inline AbstractBitfieldDataInformation::Type SignedBitfieldDataInformation::bitfieldType() const
+{
+    return AbstractBitfieldDataInformation::Signed;
+}
+
 #endif /* SIGNEDBITFIELDDATAINFORMATION_H_ */
