@@ -23,10 +23,10 @@
 #ifndef STRUCTTOOLVIEW_H_
 #define STRUCTTOOLVIEW_H_
 // lib
-#include "oktetakastencontrollers_export.h"
+#include <kasten/okteta/oktetakastencontrollers_export.h>
 
 // Kasten gui
-#include <abstracttoolview.h>
+#include <kasten/abstracttoolview.h>
 
 namespace Kasten
 {
