@@ -24,12 +24,12 @@
 #define BYTEARRAYRANDOMDATAGENERATORCONFIGEDITORFACTORY_H
 
 // lib
-#include "oktetakastengui_export.h"
+#include <kasten/okteta/oktetakastengui_export.h>
 // Kasten gui
-#include <abstractmodeldatageneratorconfigeditorfactory.h>
+#include <kasten/abstractmodeldatageneratorconfigeditorfactory.h>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class ByteArrayRandomDataGeneratorConfigEditorFactory : public AbstractModelDataGeneratorConfigEditorFactory
