@@ -26,13 +26,13 @@
 // lib
 #include "abstractbytearraycolumntextrenderer.h"
 // Okteta core
-#include <oktetacore.h>
+#include <okteta/oktetacore.h>
 
 namespace Okteta {
 class ValueCodec;
 }
 
-namespace Kasten2
+namespace Kasten
 {
 
 class ValueByteArrayColumnTextRenderer : public AbstractByteArrayColumnTextRenderer
