@@ -23,10 +23,10 @@
 #include "modifiedbarcontroller.h"
 
 // Kasten ui
-#include <statusbar.h>
+#include <kasten/statusbar.h>
 // Kasten core
-#include <abstractmodelsynchronizer.h>
-#include <abstractdocument.h>
+#include <kasten/abstractmodelsynchronizer.h>
+#include <kasten/abstractdocument.h>
 // KF5
 #include <KLocalizedString>
 // Qt
