@@ -24,7 +24,7 @@
 #define INSERTDIALOG_H
 
 // Qt
-#include <QtWidgets/QDialog>
+#include <QDialog>
 
 
 namespace Kasten
