@@ -22,13 +22,4 @@
 
 #include "kastencore.h"
 
-// KDE
-#include <KGlobal>
-
-
-namespace Kasten2
-{
-
-static const KCatalogLoader catalogLoader( QLatin1String("libkasten") );
-
-}
+Q_LOGGING_CATEGORY(LOG_KASTEN_CORE, "kasten.core")
