@@ -24,7 +24,7 @@
 #define ABSTRACTLINEPOPUP_H
 
 // lib
-#include "kastengui_export.h"
+#include <kasten/kastengui_export.h>
 // Qt
 #include <QWidget>
 
