@@ -28,13 +28,13 @@
 #include "multiviewareas.h"
 #include "tabbedviews.h"
 // Qt
-#include <QtGui/QSplitter>
+#include <QSplitter>
 
 class QDragMoveEvent;
 class QDropEvent;
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class TabbedViews;
