@@ -24,9 +24,9 @@
 #define ABSTRACTSELECTIONVIEW_H
 
 // lib
-#include "kastengui_export.h"
+#include <kasten/kastengui_export.h>
 // Qt
-#include <QtCore/QObject>
+#include <QObject>
 
 class QWidget;
 
