@@ -26,10 +26,10 @@
 #include <Qt>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
-class AbstractToolInlineView::Private
+class Q_DECL_HIDDEN AbstractToolInlineView::Private
 {
   public:
     explicit Private( AbstractToolInlineView* view );
