@@ -24,9 +24,9 @@
 #define ABSTRACTVIEW_H
 
 // lib
-#include "kastengui_export.h"
+#include <kasten/kastengui_export.h>
 // Kasten core
-#include <abstractdocument.h>
+#include <kasten/abstractdocument.h>
 
 class QWidget;
 
