@@ -26,45 +26,45 @@
 #include "partfactory.h"
 #include "browserextension.h"
 // Okteta Kasten
-#include <bytearraydocument.h>
-#include <bytearrayview.h>
-#include <bytearrayviewprofilesynchronizer.h>
-#include <bytearrayviewprofilemanager.h>
-#include <filesystem/bytearrayrawfilesynchronizerfactory.h>
-#include <overwriteonly/overwriteonlycontroller.h>
-#include <overwritemode/overwritemodecontroller.h>
-#include <gotooffset/gotooffsetcontroller.h>
-#include <selectrange/selectrangecontroller.h>
-#include <search/searchcontroller.h>
-#include <replace/replacecontroller.h>
-#include <bookmarks/bookmarkscontroller.h>
-#include <print/printcontroller.h>
-#include <viewconfig/viewconfigcontroller.h>
-#include <viewmode/viewmodecontroller.h>
-#include <viewstatus/viewstatuscontroller.h>
-#include <viewprofiles/viewprofilecontroller.h>
+#include <kasten/okteta/bytearraydocument.h>
+#include <kasten/okteta/bytearrayview.h>
+#include <kasten/okteta/bytearrayviewprofilesynchronizer.h>
+#include <kasten/okteta/bytearrayviewprofilemanager.h>
+#include <kasten/okteta/bytearrayrawfilesynchronizerfactory.h>
+#include <kasten/okteta/overwriteonlycontroller.h>
+#include <kasten/okteta/overwritemodecontroller.h>
+#include <kasten/okteta/gotooffsetcontroller.h>
+#include <kasten/okteta/selectrangecontroller.h>
+#include <kasten/okteta/searchcontroller.h>
+#include <kasten/okteta/replacecontroller.h>
+#include <kasten/okteta/bookmarkscontroller.h>
+#include <kasten/okteta/printcontroller.h>
+#include <kasten/okteta/viewconfigcontroller.h>
+#include <kasten/okteta/viewmodecontroller.h>
+#include <kasten/okteta/viewstatuscontroller.h>
+#include <kasten/okteta/viewprofilecontroller.h>
 // Kasten
-#include <jobmanager.h>
-#include <abstractloadjob.h>
-#include <abstractsyncwithremotejob.h>
-#include <document/readonly/readonlycontroller.h>
-// #include <document/readonly/readonlybarcontroller.h>
-// #include <io/synchronize/synchronizecontroller.h>
-#include <io/clipboard/clipboardcontroller.h>
-#include <io/insert/insertcontroller.h>
-#include <io/copyas/copyascontroller.h>
-#include <io/export/exportcontroller.h>
-#include <view/version/versioncontroller.h>
-#include <view/zoom/zoomcontroller.h>
-#include <view/zoom/zoombarcontroller.h>
-#include <view/select/selectcontroller.h>
+#include <kasten/jobmanager.h>
+#include <kasten/abstractloadjob.h>
+#include <kasten/abstractsyncwithremotejob.h>
+#include <kasten/readonlycontroller.h>
+// #include <kasten/readonlybarcontroller.h>
+// #include <kasten/synchronizecontroller.h>
+#include <kasten/clipboardcontroller.h>
+#include <kasten/insertcontroller.h>
+#include <kasten/copyascontroller.h>
+#include <kasten/exportcontroller.h>
+#include <kasten/versioncontroller.h>
+#include <kasten/zoomcontroller.h>
+#include <kasten/zoombarcontroller.h>
+#include <kasten/selectcontroller.h>
 // KF5
 #include <KActionCollection>
 // Qt
 #include <QWidget>
 #include <QLayout>
 #include <QUrl>
-#include <QtCore/QList>
+#include <QList>
 
 
 static const char* const UIFileName[] =
